@@ -1,7 +1,8 @@
-
-import xarray as xr
-import cordex as cx
 import json
+from warnings import warn
+
+import cordex as cx
+import xarray as xr
 
 from ..core import codes
 
@@ -10,7 +11,7 @@ def _get_varinfo(name):
     # fails silently
     try:
         return codes.get_dict(name)
-    except:
+    except Exception:
         return None
 
 
@@ -20,18 +21,18 @@ def _get_pole(ds):
     for pol in pol_names:
         if pol in ds:
             return ds[pol]
+    warn("no grid_mapping found in dataset, tried: {}".format(pol_names))
     return None
 
 
+def _get_grid_definitions(CORDEX_domain, **kwargs):
+    return cx.cordex_domain(CORDEX_domain, add_vertices=True, **kwargs)
+
+
 def _get_cordex_pole(CORDEX_domain):
     return cx.cordex_domain(CORDEX_domain).rotated_latitude_longitude
 
 
-def _set_time_units(time, units):
-    time.encoding["units"] = units
-    return time
-
-
 def _encode_time(time):
     """encode xarray time axis into cf values
 
@@ -42,7 +43,7 @@ def _encode_time(time):
 
 
 def _read_cmor_table(table):
-    return _read_json_file(cx.cordex_cmor_table(table))
+    return _read_json_file(table)
 
 
 def _read_json_file(filename):
@@ -53,7 +54,7 @@ def _read_json_file(filename):
 
 def _get_cfvarinfo(cf_varname, table):
     data = _read_cmor_table(table)
-    return data['variable_entry'][cf_varname]
+    return data["variable_entry"].get(cf_varname, None)
 
 
 def _get_time_cell_method(cf_varname, table):
@@ -62,6 +63,6 @@ def _get_time_cell_method(cf_varname, table):
 
 def _strip_time_cell_method(cfvarinfo):
     try:
-        return cfvarinfo['cell_methods'].split('time:')[1].strip()
-    except:
-        return None
\ No newline at end of file
+        return cfvarinfo["cell_methods"].split("time:")[1].strip()
+    except Exception:
+        return None
